package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/MethodParameter.class */
public class MethodParameter implements Cloneable {
    private int nameIndex;
    private int accessFlags;

    public MethodParameter() {
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public MethodParameter(DataInput input) throws IOException {
        this.nameIndex = input.readUnsignedShort();
        this.accessFlags = input.readUnsignedShort();
    }

    public void accept(Visitor v) {
        v.visitMethodParameter(this);
    }

    public MethodParameter copy() {
        try {
            return (MethodParameter) clone();
        } catch (CloneNotSupportedException e) {
            return null;
        }
    }

    public final void dump(DataOutputStream file) throws IOException {
        file.writeShort(this.nameIndex);
        file.writeShort(this.accessFlags);
    }

    public int getAccessFlags() {
        return this.accessFlags;
    }

    public int getNameIndex() {
        return this.nameIndex;
    }

    public String getParameterName(ConstantPool constantPool) {
        if (this.nameIndex == 0) {
            return null;
        }
        return constantPool.getConstantUtf8(this.nameIndex).getBytes();
    }

    public boolean isFinal() {
        return (this.accessFlags & 16) != 0;
    }

    public boolean isMandated() {
        return (this.accessFlags & (-32768)) != 0;
    }

    public boolean isSynthetic() {
        return (this.accessFlags & 4096) != 0;
    }

    public void setAccessFlags(int accessFlags) {
        this.accessFlags = accessFlags;
    }

    public void setNameIndex(int nameIndex) {
        this.nameIndex = nameIndex;
    }
}
